# R-SCRIPT and EXAMPLE DATA to extract incubation from temperature measurements as described in

# Biparental incubation patterns in a high Arctic-breeding shorebird: how do pairs divide their duties? 
	# by M. Bulla, M. Valcu, A. L. Rutten, and B. Kempenaers
	# published in Behavioral Ecology, doi:10.1093/beheco/art098.

#--------------------------------------------------------------------------------------------------------

# The script 
	# is optimized for data sets with per 5 seconds temperature readings (example data: 5s.txt) as well as for data sets with per 2 minutes temperature readings (artificially spread to each 5 second; example data: 2m.txt), and 
	#runs with R (Version 2.15.13) and packages zoo (Version 1.7-10)

# Data collection and how the individual variables and threshold values were derived is described in the paper and its supplementaries.

# Example data sets are available as 2 text files (values are separated by semi-colon).

#--------------------------------------------------------------------------------------------------------

# Load packages and set working directory
	#install.packages("zoo")
	require(zoo)
	setwd("M:\\PROJECTS\\PHD\\STATS\\DATASETS\\") # set the working directory to load the datasets from

# Load example data sets or create data set named "b" with following variables
		# nest (unique identity of the nest)
		# datetime_ (date and time of the sampled datapoint)
		# t_nest (nest incubation temperature in C)
		# t_ambient (tundra temperature next to the nest in C)
	b=read.table('2m.txt',sep = ";",header=TRUE) # 2 min dataset (spread to each 5s)
		#b=read.table('5s.txt',sep = ";",header=TRUE) # 5 s dataset
	
# Define variables		
		b$datetime_= as.POSIXct(strptime(b$datetime_, format="%Y-%m-%d %H:%M:%S"))	
		b=b[order(b$datetime_),]
				
		b$t_nest_prior=c(b$t_nest[1],b$t_nest[-nrow(b)])
		b$t_difference = as.numeric(b$t_nest - b$t_nest_prior) # if t_difference is negative than bird left the nest, if positive, than it is incubating
							
		b$t_nest_run_med=rollmedian(b$t_nest, 17279 , fill="extend") # 1/2 day 8639, whole day 17279
		b$t_diff_run=rollmean(b$t_difference, 24, fill="extend") # 2 minutes (for median needs to be odd) -  accounts for 2 min readings in 2 min dataset and smooth out the readings in 5s dataset						

# Assignes incubation/non-incubation based on temperature
		b$inc_t = ifelse(is.na(b$t_ambient),
							(ifelse(b$t_nest_run_med<17,
								(ifelse(b$t_nest > b$t_nest_run_med+3, 1, 0)),#))
								ifelse(b$t_nest > b$t_nest_run_med-3, 1,0))),#))
								
									ifelse(b$t_nest_run_med<17,
											(ifelse(b$t_nest > b$t_nest_run_med+3, 1, 
											ifelse(b$t_nest > b$t_ambient+12.5, 1,0))),#))
												ifelse(b$t_nest > b$t_nest_run_med-3, 1, 
												ifelse(b$t_nest > b$t_ambient+12.5, 1,0))))#))
				
# Adjusts incubation/non-incubation based on increase/decrease in temperature	
		b$inc_t =  	ifelse(is.na(b$t_ambient),
							(ifelse(abs(b$t_diff_run) >= 0.02 & b$t_difference < 0, 0,
							ifelse(abs(b$t_diff_run) >= 0.02 & b$t_difference > 0, 1, NA))),
														
								ifelse(b$t_nest<17 &(b$t_ambient-abs(b$t_nest))>(-3) & b$t_nest<b$t_nest_run_med+3, b$inc_t,
												(ifelse(abs(b$t_diff_run) >= 0.02 & b$t_diff_run < 0, 0,
												ifelse(abs(b$t_diff_run) >= 0.02 & b$t_diff_run > 0,1,
												b$inc_t)))))	